package com.alihealth.d2d.provtest.service.handle.business;

import com.alihealth.d2d.provtest.domain.DomesticDrugProductionApplyInfo;
import com.alihealth.d2d.provtest.domain.DrugImportApplyInfo;
import com.alihealth.d2d.provtest.entity.EventBasic;
import com.alihealth.d2d.provtest.entity.EventBody;
import com.alihealth.d2d.provtest.entity.InstanceDetail;
import com.alihealth.d2d.provtest.entity.ItemDetail;
import com.alihealth.d2d.provtest.service.IDomesticDrugProductionApplyInfoService;
import com.alihealth.d2d.provtest.service.IDrugImportApplyInfoService;
import com.alihealth.d2d.provtest.service.handle.AbstractEventDataHandler;
import com.alihealth.d2d.provtest.service.handle.EventSubType;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

/**
 * @author Jason
 * @date 2025年06月05日 11:37:18
 */
@Service
@EventSubType("2012")
public class SubType2012Handler extends AbstractEventDataHandler<DrugImportApplyInfo> {

    @Autowired
    private IDrugImportApplyInfoService service;

    @Override
    protected Class<DrugImportApplyInfo> getEntityClass() {
        return DrugImportApplyInfo.class;
    }

    @Override
    protected IService<DrugImportApplyInfo> getService() {
        return service;
    }

    @Override
    protected DrugImportApplyInfo convertToEntity(EventBody eventBody, ItemDetail item, InstanceDetail instance) {
        EventBasic evtBasic = eventBody.getEvtBasic();
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String formattedDate = LocalDate.parse(
                item.getString("SCRQ"),
                DateTimeFormatter.ofPattern("yyyyMMdd")
        ).format(DateTimeFormatter.ISO_LOCAL_DATE); //
        try {
            return DrugImportApplyInfo.builder()
                    .eventId(eventBody.getEventID())
                    .rksj(evtBasic.getDate("RKSJ"))
                    .recTime(formatter.parse(eventBody.getRecTime()))
                    .rkdbh(evtBasic.getString("RKDBH"))
                    .ypzsm(instance.getString("YPZSM"))
                    .syjbzypzsm(instance.getString("SYJBZYPZSM"))
                    .bzcj(instance.getString("BZCJ"))
                    .ymzt(instance.getString("YMZT"))
                    .tyshxydmjkymdlqy(instance.getString("TYSHXYDMJKYMDLQY"))
                    .jkymdlqymc(instance.getString("JKYMDLQYMC"))
                    .jwypssxkcyrdm(instance.getString("JWYPPSSXKCYRDM"))
                    .jwypssxkcyrmczw(instance.getString("JWYPPSSXKCYRMCZW"))
                    .jwypscqydm(instance.getString("JWYPPSCQYDM"))
                    .jwypscqymczw(instance.getString("JWYPPSCQYMCZW"))
                    .jwypscqymczw(instance.getString("JWYPPSCQYMCZW"))
                    .tyshxydmfbzc(instance.getString("TYSHXYDMFBZC"))
                    .fbzcmc(instance.getString("FBZCMC"))
                    .yptymc(instance.getString("YPTYMC"))
                    .gjypbsm(instance.getString("GJYPBSM"))
                    .ymscph(instance.getString("YMSCPH"))
                    .scrq(instance.getDate("SCRQ"))
                    .ymyxqjzrq(instance.getDate("YMYXQJZRQ"))
                    .scsl(instance.getInt("SCSL"))
                    .createTime(instance.getDate("CREATETIME"))
                    .updateTime(instance.getDate("UPDATETIME"))
                    .isDeleted(instance.getInt("ISDELETE"))
                    .build();
        } catch (ParseException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public String getSubType() {
        return "2012";
    }

    @Override
    public void handleBase(String xml, String eventId) {

    }
}
